package com.ruoyi.invest.service;

import java.util.List;
import com.ruoyi.invest.domain.AccountsTransferRecord;
import com.ruoyi.invest.domain.dto.AccountsTransferRecordDto;
import com.ruoyi.invest.domain.vo.AccountsTransferRecordVo;

/**
 * 账户转账记录Service接口
 *
 * @author tianyongbao
 * @date 2024-03-30
 */
public interface IAccountsTransferRecordService
{
    /**
     * 查询账户转账记录
     *
     * @param id 账户转账记录主键
     * @return 账户转账记录
     */
    public AccountsTransferRecordVo selectAccountsTransferRecordById(Long id);

    /**
     * 查询账户转账记录列表
     *
     * @param accountsTransferRecordDto 账户转账记录
     * @return 账户转账记录集合
     */
    public List<AccountsTransferRecordVo> selectAccountsTransferRecordList(AccountsTransferRecordDto accountsTransferRecordDto);

    /**
     * 新增账户转账记录
     *
     * @param accountsTransferRecord 账户转账记录
     * @return 结果
     */
    public int insertAccountsTransferRecord(AccountsTransferRecord accountsTransferRecord);

    /**
     * 修改账户转账记录
     *
     * @param accountsTransferRecord 账户转账记录
     * @return 结果
     */
    public int updateAccountsTransferRecord(AccountsTransferRecord accountsTransferRecord);

    /**
     * 批量删除账户转账记录
     *
     * @param ids 需要删除的账户转账记录主键集合
     * @return 结果
     */
    public int deleteAccountsTransferRecordByIds(Long[] ids);

    /**
     * 删除账户转账记录信息
     *
     * @param id 账户转账记录主键
     * @return 结果
     */
    public int deleteAccountsTransferRecordById(Long id);
}
